@@ -1,5 +1,8 @@
 import json
-from typing import Literal
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 from unit.models import *
 
 AchReturnReason = Literal["Unauthorized"]
