@@ -465,7 +465,7 @@ class PatchTransactionRequest(BaseTransactionDTO, UnitRequest):
 
 class ListTransactionParams(UnitParams):
     def __init__(self, limit: int = 100, offset: int = 0, account_id: Optional[str] = None,
-                 customer_id: Optional[str] = None, query: Optional[str] = None, tags: Optional[object] = None,
+                 customer_id: Optional[str] = None, query: Optional[str] = None, tags: Optional[Dict[str, str]] = None,
                  since: Optional[str] = None, until: Optional[str] = None, card_id: Optional[str] = None,
                  type: Optional[List[str]] = None, exclude_fees: Optional[bool] = None,
                  sort: Optional[Literal["createdAt", "-createdAt"]] = None, include: Optional[str] = None):
@@ -492,7 +492,7 @@ class ListTransactionParams(UnitParams):
         if self.query:
             parameters["filter[query]"] = self.query
         if self.tags:
-            parameters["filter[tags]"] = self.tags
+            parameters["filter[tags]"] = json.dumps(self.tags)
         if self.since:
             parameters["filter[since]"] = self.since
         if self.until:
